@@ -19,12 +19,8 @@ def sa_middleware(key: str = DEFAULT_KEY) -> 'Callable':
         if key in request:
             raise DuplicateRequestKeyError(key)
 
-        arg = request.config_dict.get(key)
-        if isinstance(arg, AsyncEngine):
-            async with AsyncSession(arg) as request[key]:
-                return await handler(request)
-        elif isinstance(arg, sessionmaker):
-            async with arg() as request[key]:
-                return await handler(request)
+        Session = request.config_dict.get(key)
+        async with Session() as request[key]:
+            return await handler(request)
 
     return sa_middleware_
